@@ -142,13 +142,13 @@ KSquirrel::KSquirrel(TQWidget *parent, const char *name)
 
     // create TDEConfig instance.
     // It will help us to read and write config entries
-    tdeconf = new SQ_Config(TQT_TQOBJECT(this));
+    tdeconf = new SQ_Config(this);
 
     old_id = 0;
 
     tdeconf->setGroup("Thumbnails");
 
-    thumbSize = new SQ_ThumbnailSize(TQT_TQOBJECT(this), static_cast<SQ_ThumbnailSize::Size>(tdeconf->readNumEntry("size",
+    thumbSize = new SQ_ThumbnailSize(this, static_cast<SQ_ThumbnailSize::Size>(tdeconf->readNumEntry("size",
                             SQ_ThumbnailSize::Large)));
     thumbSize->setExtended(tdeconf->readBoolEntry("extended", false));
 
@@ -227,7 +227,7 @@ void KSquirrel::slotOptions()
 
 bool KSquirrel::eventFilter(TQObject *o, TQEvent *e)
 {
-    if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(mainPage) && e->type() == TQEvent::Show)
+    if(o == mainPage && e->type() == TQEvent::Show)
     {
         // delayed init, hehe...
         if(waitForShow)
@@ -248,7 +248,7 @@ bool KSquirrel::eventFilter(TQObject *o, TQEvent *e)
             if(SQ_HLOptions::instance()->have_mountview)
             {
                 sideBar->addWidget(new SQ_MountView, i18n("Mount points"), "blockdevice");
-                connect(SQ_MountView::instance(), TQT_SIGNAL(path(const TQString &)), pWidgetStack, TQT_SLOT(setURLForCurrent(const TQString &)));
+                connect(SQ_MountView::instance(), TQ_SIGNAL(path(const TQString &)), pWidgetStack, TQ_SLOT(setURLForCurrent(const TQString &)));
             }
 
             if(SQ_HLOptions::instance()->have_categories)
@@ -351,13 +351,13 @@ void KSquirrel::createLocationToolbar(TDEToolBar *pTLocation)
 
     // some additional setup
     pTLocation->setFullSize();
-    pTLocation->insertButton("button_cancel", 0, TQT_SIGNAL(clicked()), TQT_TQOBJECT(pCurrentURL), TQT_SLOT(clearHistory()), true, i18n("Clear history"));
-    pTLocation->insertButton("locationbar_erase", 1, TQT_SIGNAL(clicked()), TQT_TQOBJECT(pCurrentURL), TQT_SLOT(clearEdit()), true, i18n("Clear address"));
+    pTLocation->insertButton("button_cancel", 0, TQ_SIGNAL(clicked()), pCurrentURL, TQ_SLOT(clearHistory()), true, i18n("Clear history"));
+    pTLocation->insertButton("locationbar_erase", 1, TQ_SIGNAL(clicked()), pCurrentURL, TQ_SLOT(clearEdit()), true, i18n("Clear address"));
     pTLocation->insertWidget(2, 10, new TQLabel("URL:", pTLocation, "tde toolbar widget"));
     pTLocation->setItemAutoSized(2);
     pTLocation->insertWidget(3, 10, pCurrentURL);
     pTLocation->setItemAutoSized(3);
-    pTLocation->insertButton("goto", 4, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotGo()), true, i18n("Go!"));
+    pTLocation->insertButton("goto", 4, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotGo()), true, i18n("Go!"));
 
     tdeconf->setGroup("History");
 
@@ -455,8 +455,8 @@ void KSquirrel::initFilterMenu()
         actionFilterMenu->setItemParameter(id, i++);
     }
 
-    disconnect(actionFilterMenu, TQT_SIGNAL(activated(int)), 0, 0);
-    connect(actionFilterMenu, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetFilter(int)));
+    disconnect(actionFilterMenu, TQ_SIGNAL(activated(int)), 0, 0);
+    connect(actionFilterMenu, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSetFilter(int)));
 
     // finally, set current filter
     setFilter(last, Id);
@@ -530,14 +530,14 @@ void KSquirrel::createWidgets(int createFirst)
     pTLocation->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Minimum);
 
     // main splitter
-    mainView = new TQSplitter(Qt::Horizontal, mainPage); Q_ASSERT(mainView);
+    mainView = new TQSplitter(TQt::Horizontal, mainPage); Q_ASSERT(mainView);
 
     KStatusBar *s = new KStatusBar(mainPage);
 
     createLocationToolbar(pTLocation);
     createStatusBar(s);
 
-    new SQ_NavigatorDropMenu(TQT_TQOBJECT(this));
+    new SQ_NavigatorDropMenu(this);
 
     sideBar = new SQ_MultiBar(mainView);
 
@@ -567,15 +567,15 @@ void KSquirrel::createWidgets(int createFirst)
     sideBar->addWidget(ptree, i18n("Folder tree"), "view_tree");
     sideBar->updateLayout();
 
-    connect(ptree, TQT_SIGNAL(urlAdded(const KURL &)), pWidgetStack->diroperator(), TQT_SLOT(urlAdded(const KURL &)));
-    connect(ptree, TQT_SIGNAL(urlRemoved(const KURL &)), pWidgetStack->diroperator(), TQT_SLOT(urlRemoved(const KURL &)));
-    connect(pWidgetStack->diroperator(), TQT_SIGNAL(urlEntered(const KURL &)), ptree, TQT_SLOT(slotClearChecked()));
-    connect(pWidgetStack, TQT_SIGNAL(newLastURL(const TQString &)), pWidgetStack->action("dirop_repeat"), TQT_SLOT(setText(const TQString &)));
-    connect(SQ_PreviewWidget::instance(), TQT_SIGNAL(first()), pWidgetStack, TQT_SLOT(slotSelectFirstFile()));
-    connect(SQ_PreviewWidget::instance(), TQT_SIGNAL(last()), pWidgetStack, TQT_SLOT(slotSelectLastFile()));
-    connect(SQ_PreviewWidget::instance(), TQT_SIGNAL(next()), TQT_TQOBJECT(this), TQT_SLOT(slotPreviewWidgetNext()));
-    connect(SQ_PreviewWidget::instance(), TQT_SIGNAL(previous()), TQT_TQOBJECT(this), TQT_SLOT(slotPreviewWidgetPrevious()));
-    connect(SQ_PreviewWidget::instance(), TQT_SIGNAL(execute()), TQT_TQOBJECT(this), TQT_SLOT(slotPreviewWidgetExecute()));
+    connect(ptree, TQ_SIGNAL(urlAdded(const KURL &)), pWidgetStack->diroperator(), TQ_SLOT(urlAdded(const KURL &)));
+    connect(ptree, TQ_SIGNAL(urlRemoved(const KURL &)), pWidgetStack->diroperator(), TQ_SLOT(urlRemoved(const KURL &)));
+    connect(pWidgetStack->diroperator(), TQ_SIGNAL(urlEntered(const KURL &)), ptree, TQ_SLOT(slotClearChecked()));
+    connect(pWidgetStack, TQ_SIGNAL(newLastURL(const TQString &)), pWidgetStack->action("dirop_repeat"), TQ_SLOT(setText(const TQString &)));
+    connect(SQ_PreviewWidget::instance(), TQ_SIGNAL(first()), pWidgetStack, TQ_SLOT(slotSelectFirstFile()));
+    connect(SQ_PreviewWidget::instance(), TQ_SIGNAL(last()), pWidgetStack, TQ_SLOT(slotSelectLastFile()));
+    connect(SQ_PreviewWidget::instance(), TQ_SIGNAL(next()), this, TQ_SLOT(slotPreviewWidgetNext()));
+    connect(SQ_PreviewWidget::instance(), TQ_SIGNAL(previous()), this, TQ_SLOT(slotPreviewWidgetPrevious()));
+    connect(SQ_PreviewWidget::instance(), TQ_SIGNAL(execute()), this, TQ_SLOT(slotPreviewWidgetExecute()));
 
     pWidgetStack->init();
 
@@ -584,8 +584,8 @@ void KSquirrel::createWidgets(int createFirst)
     mainPage->setStretchFactor(mainView, 1);
 
     // connect signals from location toolbar
-    connect(pCurrentURL, TQT_SIGNAL(returnPressed(const TQString&)), pWidgetStack, TQT_SLOT(setURLForCurrent(const TQString&)));
-    connect(pCurrentURL, TQT_SIGNAL(activated(const TQString&)), pWidgetStack, TQT_SLOT(setURLForCurrent(const TQString&)));
+    connect(pCurrentURL, TQ_SIGNAL(returnPressed(const TQString&)), pWidgetStack, TQ_SLOT(setURLForCurrent(const TQString&)));
+    connect(pCurrentURL, TQ_SIGNAL(activated(const TQString&)), pWidgetStack, TQ_SLOT(setURLForCurrent(const TQString&)));
 
     gl_view = new SQ_GLView;
 
@@ -611,11 +611,11 @@ void KSquirrel::createWidgets(int createFirst)
     }
 
     // connect signals from widgets
-    connect(pAURL, TQT_SIGNAL(toggled(bool)), pTLocation, TQT_SLOT(setShown(bool)));
-    connect(pASelectGroup, TQT_SIGNAL(activated()), pWidgetStack, TQT_SLOT(slotSelectGroup()));
-    connect(pADeselectGroup, TQT_SIGNAL(activated()), pWidgetStack, TQT_SLOT(slotDeselectGroup()));
-    connect(pASelectAll, TQT_SIGNAL(activated()), pWidgetStack, TQT_SLOT(slotSelectAll()));
-    connect(pADeselectAll, TQT_SIGNAL(activated()), pWidgetStack, TQT_SLOT(slotDeselectAll()));
+    connect(pAURL, TQ_SIGNAL(toggled(bool)), pTLocation, TQ_SLOT(setShown(bool)));
+    connect(pASelectGroup, TQ_SIGNAL(activated()), pWidgetStack, TQ_SLOT(slotSelectGroup()));
+    connect(pADeselectGroup, TQ_SIGNAL(activated()), pWidgetStack, TQ_SLOT(slotDeselectGroup()));
+    connect(pASelectAll, TQ_SIGNAL(activated()), pWidgetStack, TQ_SLOT(slotSelectAll()));
+    connect(pADeselectAll, TQ_SIGNAL(activated()), pWidgetStack, TQ_SLOT(slotDeselectAll()));
 
     SQ_SplashScreen::advance();
 
@@ -663,7 +663,7 @@ void KSquirrel::createStatusBar(KStatusBar *bar)
     fireDisk->setIconSet(SQ_IconLoader::instance()->loadIcon("reload", TDEIcon::Desktop, TDEIcon::SizeSmall));
     fireDisk->setTextLabel(i18n("Reload"));
     fireDisk->setUsesTextLabel(false);
-    connect(fireDisk, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotFireDisk()));
+    connect(fireDisk, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotFireDisk()));
 
     diskProg = new SQ_Progress(sbar, "SQ_Progress [disk space]");
     diskProg->setFixedWidth(150);
@@ -788,37 +788,37 @@ void KSquirrel::createToolbar(TDEToolBar *tools)
 void KSquirrel::createActions()
 {
     pAThumbs = new TDEActionMenu(i18n("Thumbnail size"), "thumbnail");
-    pAExit = KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotClose()), actionCollection(), "SQ close");
-    pAConfigure = KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotOptions()), actionCollection(), "SQ Configure");
-    pAGLView = new TDEAction(i18n("Image window"), "raise", CTRL+TQt::Key_I, TQT_TQOBJECT(this), TQT_SLOT(raiseGLWidget()), actionCollection(), "SQ gl view widget");
-    pARescan = KStdAction::redisplay(TQT_TQOBJECT(this), TQT_SLOT(slotRescan()), actionCollection(), "SQ rescan libraries");
+    pAExit = KStdAction::quit(this, TQ_SLOT(slotClose()), actionCollection(), "SQ close");
+    pAConfigure = KStdAction::preferences(this, TQ_SLOT(slotOptions()), actionCollection(), "SQ Configure");
+    pAGLView = new TDEAction(i18n("Image window"), "raise", CTRL+TQt::Key_I, this, TQ_SLOT(raiseGLWidget()), actionCollection(), "SQ gl view widget");
+    pARescan = KStdAction::redisplay(this, TQ_SLOT(slotRescan()), actionCollection(), "SQ rescan libraries");
     pARescan->setText(i18n("Reload codecs from disk"));
-    pAExtTools = new TDEAction(i18n("Configure external tools..."), "launch", 0, TQT_TQOBJECT(this), TQT_SLOT(slotExtTools()), actionCollection(), "SQ external tools");
-    pAFilters = new TDEAction(i18n("Configure filters..."), "filefind", 0, TQT_TQOBJECT(this), TQT_SLOT(slotFilters()), actionCollection(), "SQ filters");
-    pAGotoTray = new TDEAction(i18n("Go to tray"), "background", CTRL+TQt::Key_T, TQT_TQOBJECT(this), TQT_SLOT(slotGotoTray()), actionCollection(), "SQ goto tray");
-    pAOpenAndSet = new TDEAction(i18n("Open file and change directory"), "document-open", CTRL+ALT+TQt::Key_O, TQT_TQOBJECT(this), TQT_SLOT(slotOpenFileAndSet()), actionCollection(), "SQ open and set");
-    pAOpen = new TDEAction(i18n("Open file"), "document-open", CTRL+TQt::Key_O, TQT_TQOBJECT(this), TQT_SLOT(slotOpenFile()), actionCollection(), "SQ open file");
-    pATCMaster = new TDEAction(i18n("Thumbnail cache manager..."), "cache", 0, TQT_TQOBJECT(this), TQT_SLOT(slotTCMaster()), actionCollection(), "SQ TC Master");
+    pAExtTools = new TDEAction(i18n("Configure external tools..."), "launch", 0, this, TQ_SLOT(slotExtTools()), actionCollection(), "SQ external tools");
+    pAFilters = new TDEAction(i18n("Configure filters..."), "filefind", 0, this, TQ_SLOT(slotFilters()), actionCollection(), "SQ filters");
+    pAGotoTray = new TDEAction(i18n("Go to tray"), "background", CTRL+TQt::Key_T, this, TQ_SLOT(slotGotoTray()), actionCollection(), "SQ goto tray");
+    pAOpenAndSet = new TDEAction(i18n("Open file and change directory"), "document-open", CTRL+ALT+TQt::Key_O, this, TQ_SLOT(slotOpenFileAndSet()), actionCollection(), "SQ open and set");
+    pAOpen = new TDEAction(i18n("Open file"), "document-open", CTRL+TQt::Key_O, this, TQ_SLOT(slotOpenFile()), actionCollection(), "SQ open file");
+    pATCMaster = new TDEAction(i18n("Thumbnail cache manager..."), "cache", 0, this, TQ_SLOT(slotTCMaster()), actionCollection(), "SQ TC Master");
     pASelectAll = KStdAction::selectAll(0, 0, actionCollection(), "SQ Select All");
     pADeselectAll = KStdAction::deselect(0, 0, actionCollection(), "SQ Deselect All");
 
-    pARaiseListView = new TDERadioAction(i18n("List"), "view_multicolumn", 0, TQT_TQOBJECT(this), TQT_SLOT(slotRaiseListView()), actionCollection(), "SQ raise list view");
-    pARaiseIconView = new TDERadioAction(i18n("Icons"), "view_icon", 0, TQT_TQOBJECT(this), TQT_SLOT(slotRaiseIconView()), actionCollection(), "SQ raise icon view");
-    pARaiseDetailView = new TDERadioAction(i18n("Details"), "view_detailed", 0, TQT_TQOBJECT(this), TQT_SLOT(slotRaiseDetailView()), actionCollection(), "SQ raise detailed view");
-    pARaiseThumbView = new TDERadioAction(i18n("Thumbnails"), "view_icon", 0, TQT_TQOBJECT(this), TQT_SLOT(slotRaiseThumbView()), actionCollection(), "SQ raise thumbs view");
+    pARaiseListView = new TDERadioAction(i18n("List"), "view_multicolumn", 0, this, TQ_SLOT(slotRaiseListView()), actionCollection(), "SQ raise list view");
+    pARaiseIconView = new TDERadioAction(i18n("Icons"), "view_icon", 0, this, TQ_SLOT(slotRaiseIconView()), actionCollection(), "SQ raise icon view");
+    pARaiseDetailView = new TDERadioAction(i18n("Details"), "view_detailed", 0, this, TQ_SLOT(slotRaiseDetailView()), actionCollection(), "SQ raise detailed view");
+    pARaiseThumbView = new TDERadioAction(i18n("Thumbnails"), "view_icon", 0, this, TQ_SLOT(slotRaiseThumbView()), actionCollection(), "SQ raise thumbs view");
 
     pAURL = new TDEToggleAction(i18n("Show URL box"), "history", CTRL+TQt::Key_U, 0, 0, actionCollection(), "SQ toggle url box");
 
-    pASlideShow = new TDEAction(i18n("Slideshow"), "folder_video", CTRL+TQt::Key_S, TQT_TQOBJECT(this), TQT_SLOT(slotSlideShowStart()), actionCollection(), "SQ Slideshow");
-    pASlideShowDialog = new TDEAction(i18n("Slideshow advanced"), 0, CTRL+ALT+TQt::Key_S, TQT_TQOBJECT(this), TQT_SLOT(slotSlideShowDialog()), actionCollection(), "SQ SlideShow Dialog");
-    pARename = new TDEAction(i18n("Rename"), "file_move", TQt::Key_F2, TQT_TQOBJECT(this), TQT_SLOT(slotRename()), actionCollection(), "SQ Rename");
-    pAPluginsInfo = new TDEAction(i18n("Codec information..."), "application-vnd.tde.info", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPluginsInfo()), actionCollection(), "SQ Plugins Info");
-    pAPluginsDel = new TDEAction(i18n("Codec manager..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotPluginsDel()), actionCollection(), "SQ Plugins Deleter");
-    pAGLInfo = new TDEAction(i18n("OpenGL information..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotGLInfo()), actionCollection(), "SQ OpenGL Info");
+    pASlideShow = new TDEAction(i18n("Slideshow"), "folder_video", CTRL+TQt::Key_S, this, TQ_SLOT(slotSlideShowStart()), actionCollection(), "SQ Slideshow");
+    pASlideShowDialog = new TDEAction(i18n("Slideshow advanced"), 0, CTRL+ALT+TQt::Key_S, this, TQ_SLOT(slotSlideShowDialog()), actionCollection(), "SQ SlideShow Dialog");
+    pARename = new TDEAction(i18n("Rename"), "file_move", TQt::Key_F2, this, TQ_SLOT(slotRename()), actionCollection(), "SQ Rename");
+    pAPluginsInfo = new TDEAction(i18n("Codec information..."), "application-vnd.tde.info", 0, this, TQ_SLOT(slotPluginsInfo()), actionCollection(), "SQ Plugins Info");
+    pAPluginsDel = new TDEAction(i18n("Codec manager..."), 0, 0, this, TQ_SLOT(slotPluginsDel()), actionCollection(), "SQ Plugins Deleter");
+    pAGLInfo = new TDEAction(i18n("OpenGL information..."), 0, 0, this, TQ_SLOT(slotGLInfo()), actionCollection(), "SQ OpenGL Info");
 
-    pAThumb1 = new TDERadioAction(i18n("Medium thumbnails"), locate("data", "images/thumbs/thumbs_medium.png"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotThumbsMedium()), actionCollection(), "SQ thumbs1");
-    pAThumb2 = new TDERadioAction(i18n("Large thumbnails"), locate("data", "images/thumbs/thumbs_large.png"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotThumbsLarge()), actionCollection(), "SQ thumbs2");
-    pAThumb3 = new TDERadioAction(i18n("Huge thumbnails"), locate("data", "images/thumbs/thumbs_huge.png"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotThumbsHuge()), actionCollection(), "SQ thumbs3");
+    pAThumb1 = new TDERadioAction(i18n("Medium thumbnails"), locate("data", "images/thumbs/thumbs_medium.png"), 0, this, TQ_SLOT(slotThumbsMedium()), actionCollection(), "SQ thumbs1");
+    pAThumb2 = new TDERadioAction(i18n("Large thumbnails"), locate("data", "images/thumbs/thumbs_large.png"), 0, this, TQ_SLOT(slotThumbsLarge()), actionCollection(), "SQ thumbs2");
+    pAThumb3 = new TDERadioAction(i18n("Huge thumbnails"), locate("data", "images/thumbs/thumbs_huge.png"), 0, this, TQ_SLOT(slotThumbsHuge()), actionCollection(), "SQ thumbs3");
 
     pASelectGroup = new TDEAction(i18n("Select group"), "zoom-in", CTRL+TQt::Key_Plus, 0, 0, actionCollection(), "SQ Select Group");
     pADeselectGroup = new TDEAction(i18n("Deselect group"), "zoom-out", CTRL+TQt::Key_Minus, 0, 0, actionCollection(), "SQ Deselect Group");
@@ -844,7 +844,7 @@ void KSquirrel::createActions()
     pAThumbsE = new TDEToggleAction(i18n("Extended thumbnails"), "", CTRL+TQt::Key_E, 0, 0, actionCollection(), "SQ Extended thumbs");
     tdeconf->setGroup("Thumbnails");
     pAThumbsE->setChecked(tdeconf->readBoolEntry("extended", false));
-    connect(pAThumbsE, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotExtendedToggled(bool)));
+    connect(pAThumbsE, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotExtendedToggled(bool)));
     pAThumbs->insert(pAThumbsE);
 
     pAThumbs->setDelayed(false);
@@ -876,7 +876,7 @@ void KSquirrel::initExternalTools()
 {
     // create SQ_ExternalTool and create new
     // popup menu with tools
-    extool = new SQ_ExternalTool(TQT_TQOBJECT(this));
+    extool = new SQ_ExternalTool(this);
     extool->newPopupMenu();
 }
 
@@ -955,7 +955,7 @@ void KSquirrel::initBookmarks()
     bookmarks = new TDEActionMenu(i18n("&Bookmarks"), "bookmark", actionCollection(), "bookmarks");
     bookmarkMenu = new KBookmarkMenu(bmanager, bookmarkOwner, bookmarks->popupMenu(), actionCollection(), true);
 
-    connect(bookmarkOwner, TQT_SIGNAL(openURL(const KURL&)), pWidgetStack, TQT_SLOT(setURLForCurrent(const KURL&)));
+    connect(bookmarkOwner, TQ_SIGNAL(openURL(const KURL&)), pWidgetStack, TQ_SLOT(setURLForCurrent(const KURL&)));
 
     bookmarkOwner->setURL(pWidgetStack->diroperator()->url());
 }
@@ -1229,40 +1229,40 @@ void KSquirrel::enableThumbsMenu(bool enable)
  */
 void KSquirrel::preCreate()
 {
-    new SQ_IconLoader(TQT_TQOBJECT(this));
-    new SQ_PixmapCache(TQT_TQOBJECT(this));
-    new SQ_ArchiveHandler(TQT_TQOBJECT(this));
-    new SQ_ImageLoader(TQT_TQOBJECT(this));
-    new SQ_DragProvider(TQT_TQOBJECT(this));
+    new SQ_IconLoader(this);
+    new SQ_PixmapCache(this);
+    new SQ_ArchiveHandler(this);
+    new SQ_ImageLoader(this);
+    new SQ_DragProvider(this);
 
-    libhandler = new SQ_LibraryHandler(TQT_TQOBJECT(this));
+    libhandler = new SQ_LibraryHandler(this);
 
     initExternalTools();
 
-    new SQ_ErrorString(TQT_TQOBJECT(this));
-    new SQ_ThumbnailsUnused(TQT_TQOBJECT(this));
-    new SQ_Converter(TQT_TQOBJECT(this));
+    new SQ_ErrorString(this);
+    new SQ_ThumbnailsUnused(this);
+    new SQ_Converter(this);
 
     listingDialog = new SQ_SlideShowListing(this, "SlideShow Listing", true, TQt::WStyle_Customize | TQt::WStyle_NoBorder);
-    connect(listingDialog, TQT_SIGNAL(kill()), TQT_TQOBJECT(this), TQT_SLOT(slotSlideShowListingKill()));
+    connect(listingDialog, TQ_SIGNAL(kill()), this, TQ_SLOT(slotSlideShowListingKill()));
 
     slideShowItems.setAutoDelete(true);
 
-    down = new SQ_Downloader(TQT_TQOBJECT(this));
+    down = new SQ_Downloader(this);
 
-    connect(down, TQT_SIGNAL(result(const KURL &)), TQT_TQOBJECT(this), TQT_SLOT(slotDownloaderResult(const KURL &)));
+    connect(down, TQ_SIGNAL(result(const KURL &)), this, TQ_SLOT(slotDownloaderResult(const KURL &)));
 
     SQ_SlideShowWidget *sls = new SQ_SlideShowWidget(0, "ksquirrel-slideshow");
 
-    connect(sls, TQT_SIGNAL(stopSlideShow()), TQT_TQOBJECT(this), TQT_SLOT(slotStopSlideShow()));
-    connect(sls, TQT_SIGNAL(pause()), TQT_TQOBJECT(this), TQT_SLOT(slotPauseSlideShow()));
-    connect(sls, TQT_SIGNAL(next()), TQT_TQOBJECT(this), TQT_SLOT(slotNextSlideShow()));
-    connect(sls, TQT_SIGNAL(previous()), TQT_TQOBJECT(this), TQT_SLOT(slotPreviousSlideShow()));
+    connect(sls, TQ_SIGNAL(stopSlideShow()), this, TQ_SLOT(slotStopSlideShow()));
+    connect(sls, TQ_SIGNAL(pause()), this, TQ_SLOT(slotPauseSlideShow()));
+    connect(sls, TQ_SIGNAL(next()), this, TQ_SLOT(slotNextSlideShow()));
+    connect(sls, TQ_SIGNAL(previous()), this, TQ_SLOT(slotPreviousSlideShow()));
 
     // timer for slideshow
     slideShowTimer = new TQTimer(this);
     timerShowListing = new TQTimer(this);
-    connect(timerShowListing, TQT_SIGNAL(timeout()), listingDialog, TQT_SLOT(show()));
+    connect(timerShowListing, TQ_SIGNAL(timeout()), listingDialog, TQ_SLOT(show()));
 
     SQ_SplashScreen::advance();
 
@@ -1303,7 +1303,7 @@ void KSquirrel::preCreate()
         TDEIO::StatJob *job = TDEIO::stat(url, false);
         job->setSide(true);
         job->setDetails(0);
-        connect(job, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotStatResult(TDEIO::Job *)));
+        connect(job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotStatResult(TDEIO::Job *)));
     }
     else
         continueLoading();
@@ -1367,7 +1367,7 @@ void KSquirrel::slotStatResult(TDEIO::Job *_job)
         TDEIO::StatJob *job2 = TDEIO::stat(url, false);
         job2->setSide(true);
         job2->setDetails(0);
-        connect(job2, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotStatResult(TDEIO::Job *)));
+        connect(job2, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotStatResult(TDEIO::Job *)));
     }
     else
         continueLoading();
@@ -1401,13 +1401,13 @@ void KSquirrel::continueLoading()
     if(mainPage->isVisible())
     {
         TQEvent e(TQEvent::Show);
-        eventFilter(TQT_TQOBJECT(mainPage), &e);
+        eventFilter(mainPage, &e);
     }
 
     tray = new KSystemTray(this);
     tray->setPixmap(TQPixmap(locate("data", "images/tray.png")));
 
-    connect(tray, TQT_SIGNAL(quitSelected()), TQT_TQOBJECT(this), TQT_SLOT(slotTrayQuit()));
+    connect(tray, TQ_SIGNAL(quitSelected()), this, TQ_SLOT(slotTrayQuit()));
 
     SQ_SplashScreen::advance();
     SQ_SplashScreen::finish();
@@ -1432,7 +1432,7 @@ void KSquirrel::continueLoading()
     if(kapp->isRestored())
         slotGotoTray();
 
-    connect(kapp, TQT_SIGNAL(saveYourself()), TQT_TQOBJECT(this), TQT_SLOT(slotSaveYourself()));
+    connect(kapp, TQ_SIGNAL(saveYourself()), this, TQ_SLOT(slotSaveYourself()));
 }
 
 // Set caption to main window or to image window
@@ -1578,7 +1578,7 @@ bool KSquirrel::process(const TQCString &fun, const TQByteArray &data, TQCString
         TDEIO::StatJob *job = TDEIO::stat(url, false);
         job->setSide(true);
         job->setDetails(0);
-        connect(job, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotDCOPStatResult(TDEIO::Job *)));
+        connect(job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotDCOPStatResult(TDEIO::Job *)));
 
         replyType = "void";
 
@@ -1816,10 +1816,10 @@ void KSquirrel::slotSlideShowStart()
     listing = recurs ? TDEIO::listRecursive(slideShowDir, false, false)
                      : TDEIO::listDir(slideShowDir, false, false);
 
-    connect(listing, TQT_SIGNAL(entries(TDEIO::Job *, const TDEIO::UDSEntryList &)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotSlideShowEntries(TDEIO::Job *, const TDEIO::UDSEntryList &)));
+    connect(listing, TQ_SIGNAL(entries(TDEIO::Job *, const TDEIO::UDSEntryList &)),
+            this, TQ_SLOT(slotSlideShowEntries(TDEIO::Job *, const TDEIO::UDSEntryList &)));
 
-    connect(listing, TQT_SIGNAL(result(TDEIO::Job *)), TQT_TQOBJECT(this), TQT_SLOT(slotSlideShowJobResult(TDEIO::Job *)));
+    connect(listing, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotSlideShowJobResult(TDEIO::Job *)));
 
     timerShowListing->start(1000, true);
 }
@@ -1889,8 +1889,8 @@ void KSquirrel::slideShowPrivate()
     slideShowInit = true;
     slideShowDirection = KSquirrel::Default;
 
-    disconnect(slideShowTimer, TQT_SIGNAL(timeout()), 0, 0);
-    connect(slideShowTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(slotSlideShowNextImage()));
+    disconnect(slideShowTimer, TQ_SIGNAL(timeout()), 0, 0);
+    connect(slideShowTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotSlideShowNextImage()));
 
     tdeconf->setGroup("Slideshow");
 
@@ -1917,7 +1917,7 @@ void KSquirrel::slideShowPrivate()
     // start!
     SQ_SlideShowWidget::instance()->beginSlideShow(slideShowTotal);
 
-    TQTimer::singleShot(1, TQT_TQOBJECT(this), TQT_SLOT(slideShowDetermine()));
+    TQTimer::singleShot(1, this, TQ_SLOT(slideShowDetermine()));
 }
 
 void KSquirrel::slotDownloaderResult(const KURL &u)
@@ -1956,8 +1956,8 @@ void KSquirrel::slideShowDetermine()
                 if(!slideShowRepeat)
                 {
                     // nice hack to make final delay
-                    disconnect(slideShowTimer, TQT_SIGNAL(timeout()), 0, 0);
-                    connect(slideShowTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(slotStopSlideShow()));
+                    disconnect(slideShowTimer, TQ_SIGNAL(timeout()), 0, 0);
+                    connect(slideShowTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotStopSlideShow()));
                     slideShowTimer->start(slideShowDelay, true);
                     return;
                 }
@@ -2123,7 +2123,7 @@ void KSquirrel::configAnime(bool init)
     // show animated logo in toolbar if needed
     if(!tdeconf->readBoolEntry("anime_dont", false) && (init || (!init && !anim)))
     {
-        tools->insertAnimatedWidget(1000, TQT_TQOBJECT(this), TQT_SLOT(slotAnimatedClicked()), locate("data", "images/anime.png"));
+        tools->insertAnimatedWidget(1000, this, TQ_SLOT(slotAnimatedClicked()), locate("data", "images/anime.png"));
         tools->alignItemRight(1000);
         tools->animatedWidget(1000)->start();
     }
@@ -2168,7 +2168,7 @@ void KSquirrel::slotRename()
     renameDestURL.setFileName(mNewFilename);
 
     TDEIO::Job *job = TDEIO::move(renameSrcURL, renameDestURL);
-    connect(job, TQT_SIGNAL(result(TDEIO::Job*)), TQT_TQOBJECT(this), TQT_SLOT(slotRenameResult(TDEIO::Job*)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotRenameResult(TDEIO::Job*)));
 }
 
 void KSquirrel::slotRenameResult(TDEIO::Job *job)
