@@ -71,7 +71,7 @@ class SQ_ToolBar : public TDEToolBar
 
 class SQ_GLView : public TQVBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public: 
