@@ -39,13 +39,13 @@ SQ_NavigatorDropMenu::SQ_NavigatorDropMenu(TQObject *parent) : TQObject(parent)
     dropmenu = new SQ_PopupMenu(0);
 
     // "copy" action
-    TDEAction *pACopy = new TDEAction(i18n("Copy here"), "edit-paste", 0, this, TQT_SLOT(slotCopy()), ac, "sq_copy");
+    TDEAction *pACopy = new TDEAction(i18n("Copy here"), "edit-paste", 0, this, TQ_SLOT(slotCopy()), ac, "sq_copy");
 
     // "move" action
-    TDEAction *pAMove = new TDEAction(i18n("Move here"), 0, 0, this, TQT_SLOT(slotMove()), ac, "sq_move");
+    TDEAction *pAMove = new TDEAction(i18n("Move here"), 0, 0, this, TQ_SLOT(slotMove()), ac, "sq_move");
 
     // "link" action
-    TDEAction *pALink = new TDEAction(i18n("Link here"), "www", 0, this, TQT_SLOT(slotLink()), ac, "sq_link");
+    TDEAction *pALink = new TDEAction(i18n("Link here"), "www", 0, this, TQ_SLOT(slotLink()), ac, "sq_link");
 
     // "cancel" action, this action will do nothing - just close popup menu
     TDEAction *pACancel = new TDEAction(i18n("Cancel"), 0, 0, 0, 0, ac, "sq_cancel");
@@ -69,7 +69,7 @@ void SQ_NavigatorDropMenu::slotCopy()
     if(also) emit done(url, SQ_NavigatorDropMenu::Copy);
 
     TDEIO::Job *job = TDEIO::copy(list, url);
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)), this, TQT_SLOT(slotJobResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotJobResult(TDEIO::Job *)));
 }
 
 void SQ_NavigatorDropMenu::slotMove()
@@ -77,7 +77,7 @@ void SQ_NavigatorDropMenu::slotMove()
     if(also) emit done(url, SQ_NavigatorDropMenu::Move);
 
     TDEIO::Job *job = TDEIO::move(list, url);
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)), this, TQT_SLOT(slotJobResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotJobResult(TDEIO::Job *)));
 }
 
 void SQ_NavigatorDropMenu::slotLink()
@@ -85,7 +85,7 @@ void SQ_NavigatorDropMenu::slotLink()
     if(also) emit done(url, SQ_NavigatorDropMenu::Link);
 
     TDEIO::Job *job = TDEIO::link(list, url);
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)), this, TQT_SLOT(slotJobResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotJobResult(TDEIO::Job *)));
 }
 
 void SQ_NavigatorDropMenu::slotJobResult(TDEIO::Job *job)
