@@ -26,14 +26,14 @@
 #include <tqtimer.h>
 #include <tqapplication.h>
 
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcombobox.h>
 #include <kstandarddirs.h>
-#include <kstdaccel.h>
-#include <klocale.h>
-#include <kio/job.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdestdaccel.h>
+#include <tdelocale.h>
+#include <tdeio/job.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <kstringhandler.h>
 
 #include "ksquirrel.h"
@@ -89,13 +89,13 @@ SQ_WidgetStack::SQ_WidgetStack(TQWidget *parent, const int id) : TQObject(parent
 
     raiseWidget(m_type, false);
 
-    connect(KSquirrel::app(), TQT_SIGNAL(thumbSizeChanged(const TQString&)), dirop, TQT_SLOT(slotSetThumbSize(const TQString&)));
-    connect(dirop, TQT_SIGNAL(runSeparately(KFileItem *)), this, TQT_SLOT(slotRunSeparately()));
+    connect(KSquirrel::app(), TQ_SIGNAL(thumbSizeChanged(const TQString&)), dirop, TQ_SLOT(slotSetThumbSize(const TQString&)));
+    connect(dirop, TQ_SIGNAL(runSeparately(KFileItem *)), this, TQ_SLOT(slotRunSeparately()));
 
     KSquirrel::app()->historyCombo()->setEditText(url.isLocalFile() ? url.path() : url.prettyURL());
 
     timerShowProgress = new TQTimer(this);
-    connect(timerShowProgress, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotDelayedShowProgress()));
+    connect(timerShowProgress, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotDelayedShowProgress()));
 }
 
 SQ_WidgetStack::~SQ_WidgetStack()
@@ -116,8 +116,8 @@ void SQ_WidgetStack::init()
     fileaction = static_cast<SQ_WidgetStack::FileAction>(SQ_Config::instance()->readNumEntry("last_action", SQ_WidgetStack::Unknown));
     KURL uu = KURL::fromPathOrURL(SQ_Config::instance()->readEntry("last_url"));
 
-    connect(SQ_NavigatorDropMenu::instance(), TQT_SIGNAL(done(const KURL &, int)),
-            this, TQT_SLOT(slotTreeMenuDone(const KURL &, int)));
+    connect(SQ_NavigatorDropMenu::instance(), TQ_SIGNAL(done(const KURL &, int)),
+            this, TQ_SLOT(slotTreeMenuDone(const KURL &, int)));
 
     emitNewLastURL(uu);
 }
@@ -481,7 +481,7 @@ void SQ_WidgetStack::slotRecreateThumbnail()
 
     tv->progressBox()->show();
 
-    TQTimer::singleShot(1, this, TQT_SLOT(slotDelayedRecreateThumbnail()));
+    TQTimer::singleShot(1, this, TQ_SLOT(slotDelayedRecreateThumbnail()));
 }
 
 void SQ_WidgetStack::slotDelayedRecreateThumbnail()
@@ -562,14 +562,14 @@ void SQ_WidgetStack::slotFilePaste()
     // get current url
     KURL _url = url();
     emitNewLastURL(_url);
-    KIO::Job *job;
+    TDEIO::Job *job;
 
     // now copy or move files to current url
-    job = (fileaction == SQ_WidgetStack::Copy) ? KIO::copy(files, _url) : KIO::move(files, _url);
-    connect(job, TQT_SIGNAL(result(KIO::Job *)), this, TQT_SLOT(slotJobResult(KIO::Job *)));
+    job = (fileaction == SQ_WidgetStack::Copy) ? TDEIO::copy(files, _url) : TDEIO::move(files, _url);
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotJobResult(TDEIO::Job *)));
 }
 
-void SQ_WidgetStack::slotJobResult(KIO::Job *job)
+void SQ_WidgetStack::slotJobResult(TDEIO::Job *job)
 {
     if(job && job->error())
         job->showErrorDialog(KSquirrel::app());
@@ -604,8 +604,8 @@ void SQ_WidgetStack::repeat()
     if(lastURL.isEmpty() || files.isEmpty())
         return;
 
-    KIO::Job *job = (fileaction == SQ_WidgetStack::Copy) ? KIO::copy(files, lastURL) : KIO::move(files, lastURL);
-    connect(job, TQT_SIGNAL(result(KIO::Job *)), this, TQT_SLOT(slotJobResult(KIO::Job *)));
+    TDEIO::Job *job = (fileaction == SQ_WidgetStack::Copy) ? TDEIO::copy(files, lastURL) : TDEIO::move(files, lastURL);
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(slotJobResult(TDEIO::Job *)));
 }
 
 // Create links
@@ -624,7 +624,7 @@ void SQ_WidgetStack::slotFileLinkTo()
     emitNewLastURL(url);
 
     // create symlinks
-    KIO::link(files, url);
+    TDEIO::link(files, url);
 }
 
 // Copy to...
@@ -643,7 +643,7 @@ void SQ_WidgetStack::slotFileCopyTo()
     emitNewLastURL(url);
 
     // copy files to selected directory
-    KIO::copy(files, url);
+    TDEIO::copy(files, url);
 }
 
 // Move to...
@@ -662,7 +662,7 @@ void SQ_WidgetStack::slotFileMoveTo()
     emitNewLastURL(url);
 
     // move files to selected directory
-    KIO::move(files, url);
+    TDEIO::move(files, url);
 }
 
 /*
@@ -751,7 +751,7 @@ void SQ_WidgetStack::slotSelectAll()
     }
 }
 
-KAction* SQ_WidgetStack::action(const TQString &name)
+TDEAction* SQ_WidgetStack::action(const TQString &name)
 {
     return dirop->actionCollection()->action(name);
 }
